@@ -39,8 +39,8 @@ class TargetPreModelAnalysis:
         value_counts = target.value_counts()
         percentages = np.array(value_counts / target.size * 100)
         fig, ax1 = plt.subplots()
-        plt.figure(figsize=(10, 10))
-        plt.rcParams.update({'font.size': 12})
+        # plt.figure(figsize=(10, 10))
+        # plt.rcParams.update({'font.size': 12})
         ax2 = ax1.twinx()
         ax1.bar(value_counts.index, value_counts.values, color='gray')
         ax1.set_ylabel('Counts', color='gray')
